bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.get_shape
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.get_shape